pub struct BincodeConfig {
pub limit: usize,
pub buf_size: usize,
}Expand description
Config for the extractor
use actix_bincode::config::BincodeConfig;
use actix_web::App;
let config = BincodeConfig::default();
let app = App::new().app_data(config); Fields
limit: usizeThe maximum size in bytes of a request payload that can be deserialized.
By default set to DEFAULT_LIMIT_BYTES
buf_size: usizeThe default buffer size that gets allocated for single payload.
By default set to same as user set limit or DEFAULT_LIMIT_BYTES
This size may be too much for most payloads, but avoids reallocating while reading payload
Implementations